[PUSHED gdb-10-branch] arc: Rename "arc_gdbarch_features" struct

Shahab Vahedi shahab.vahedi@gmail.com
Wed Oct 7 16:03:17 GMT 2020


From: Shahab Vahedi <shahab@synopsys.com>

"arc_gdbarch_features" is a data structure containing information
about the ARC architecture: ISA version, register size, etc.
This name is misleading, because although it carries the phrase
"gdbarch", it has nothing to do with the type/interface in GDB.
Traditionaly, "gdbarch" structures are only used for that purpose.
To rectify this, this patch changes the name to "arc_arch_features".

gdb/ChangeLog:

	* arch/arc.h: Rename "arc_gdbarch_features" to
	"arc_arch_features".
	* arc-tdep.h: Likewise.
	* arc-tdep.c: Likewise.
---
 gdb/arc-tdep.c | 14 +++++++-------
 gdb/arch/arc.c | 12 ++++++------
 gdb/arch/arc.h | 12 ++++++------
 3 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/gdb/arch/arc.c b/gdb/arch/arc.c
index 8e126ca5a82..3808f9fe292 100644
--- a/gdb/arch/arc.c
+++ b/gdb/arch/arc.c
@@ -35,7 +35,7 @@
 #endif
 
 STATIC_IN_GDB target_desc *
-arc_create_target_description (const struct arc_gdbarch_features &features)
+arc_create_target_description (const struct arc_arch_features &features)
 {
   /* Create a new target description.  */
   target_desc *tdesc = allocate_target_description ();
@@ -84,10 +84,10 @@ arc_create_target_description (const struct arc_gdbarch_features &features)
 #ifndef GDBSERVER
 
 /* Wrapper used by std::unordered_map to generate hash for features set.  */
-struct arc_gdbarch_features_hasher
+struct arc_arch_features_hasher
 {
   std::size_t
-  operator() (const arc_gdbarch_features &features) const noexcept
+  operator() (const arc_arch_features &features) const noexcept
   {
     return features.hash ();
   }
@@ -95,14 +95,14 @@ struct arc_gdbarch_features_hasher
 
 /* Cache of previously created target descriptions, indexed by the hash
    of the features set used to create them.  */
-static std::unordered_map<arc_gdbarch_features,
+static std::unordered_map<arc_arch_features,
 			  const target_desc_up,
-			  arc_gdbarch_features_hasher> arc_tdesc_cache;
+			  arc_arch_features_hasher> arc_tdesc_cache;
 
 /* See arch/arc.h.  */
 
 const target_desc *
-arc_lookup_target_description (const struct arc_gdbarch_features &features)
+arc_lookup_target_description (const struct arc_arch_features &features)
 {
   /* Lookup in the cache first.  If found, return the pointer from the
      "target_desc_up" type which is a "unique_ptr".  This should be fine
diff --git a/gdb/arch/arc.h b/gdb/arch/arc.h
index a5313b1fee6..16257596748 100644
--- a/gdb/arch/arc.h
+++ b/gdb/arch/arc.h
@@ -27,9 +27,9 @@ enum arc_isa
   ARC_ISA_ARCV2	      /* such as ARC EM and ARC HS  */
 };
 
-struct arc_gdbarch_features
+struct arc_arch_features
 {
-  arc_gdbarch_features (int reg_size, arc_isa isa)
+  arc_arch_features (int reg_size, arc_isa isa)
     : reg_size (reg_size), isa (isa)
   {}
 
@@ -41,13 +41,13 @@ struct arc_gdbarch_features
   const arc_isa isa;
 
   /* Equality operator.  */
-  bool operator== (const struct arc_gdbarch_features &rhs) const
+  bool operator== (const struct arc_arch_features &rhs) const
   {
     return (reg_size == rhs.reg_size && isa == rhs.isa);
   }
 
   /* Inequality operator.  */
-  bool operator!= (const struct arc_gdbarch_features &rhs) const
+  bool operator!= (const struct arc_arch_features &rhs) const
   {
     return !(*this == rhs);
   }
@@ -71,7 +71,7 @@ struct arc_gdbarch_features
    the returned data.  */
 
 target_desc *arc_create_target_description
-	(const struct arc_gdbarch_features &features);
+	(const struct arc_arch_features &features);
 
 #else
 
@@ -79,7 +79,7 @@ target_desc *arc_create_target_description
    If nothing is found, then create one and return it.  */
 
 const target_desc *arc_lookup_target_description
-	(const struct arc_gdbarch_features &features);
+	(const struct arc_arch_features &features);
 
 #endif /* GDBSERVER */
 
diff --git a/gdb/arc-tdep.c b/gdb/arc-tdep.c
index 6f544bff78d..60c76af3352 100644
--- a/gdb/arc-tdep.c
+++ b/gdb/arc-tdep.c
@@ -1883,11 +1883,11 @@ mach_type_to_arc_isa (const unsigned long mach)
     }
 }
 
 /* Common construction code for ARC_GDBARCH_FEATURES struct.  If there
    is no ABFD, then a FEATURE with default values is returned.  */
 
-static arc_gdbarch_features
-arc_gdbarch_features_create (const bfd *abfd, const unsigned long mach)
+static arc_arch_features
+arc_arch_features_create (const bfd *abfd, const unsigned long mach)
 {
   /* Use 4 as a fallback value.  */
   int reg_size = 4;
@@ -1915,7 +1915,7 @@ arc_gdbarch_features_create (const bfd *abfd, const unsigned long mach)
      case).  */
   arc_isa isa = mach_type_to_arc_isa (mach);
 
-  return arc_gdbarch_features (reg_size, isa);
+  return arc_arch_features (reg_size, isa);
 }
 
 /* Look for obsolete core feature names in TDESC.  */
@@ -2085,9 +2085,9 @@ arc_tdesc_init (struct gdbarch_info info, const struct target_desc **tdesc,
   /* If target doesn't provide a description, use the default ones.  */
   if (!tdesc_has_registers (tdesc_loc))
     {
-      arc_gdbarch_features features
-	= arc_gdbarch_features_create (info.abfd,
-				       info.bfd_arch_info->mach);
+      arc_arch_features features
+	= arc_arch_features_create (info.abfd,
+				    info.bfd_arch_info->mach);
       tdesc_loc = arc_lookup_target_description (features);
     }
   gdb_assert (tdesc_loc != nullptr);
@@ -1883,11 +1883,11 @@ mach_type_to_arc_isa (const unsigned long mach)
 }
 
-/* Common construction code for ARC_GDBARCH_FEATURES struct.  If there
+/* Common construction code for ARC_ARCH_FEATURES struct.  If there
    is no ABFD, then a FEATURE with default values is returned.  */
 
-- 
2.28.0



More information about the Gdb-patches mailing list